# Dashboard

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**commit_message** | **str** |  | [optional] 
**from_date** | **datetime** |  | [optional] 
**from_date_license** | **datetime** |  | [optional] 
**id** | **str** |  | [optional] 
**is_common** | **bool** |  | [optional] 
**layout** | [**WidgetCells**](WidgetCells.md) |  | [optional] 
**modified** | **datetime** |  | [optional] 
**name** | **str** |  | [optional] 
**owner** | **str** |  | [optional] 
**period** | [**Period**](Period.md) |  | [optional] 
**prev_name** | **str** |  | [optional] 
**shared** | **bool** |  | [optional] 
**should_commit** | **bool** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**system** | **bool** |  | [optional] 
**to_date** | **datetime** |  | [optional] 
**vc_should_ignore** | **bool** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


